@@ -23,16 +23,16 @@ from aliyunsdkbssopenapi.endpoint import endpoint_data
 class QueryPermissionListRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryPermissionList')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryPermissionList','bssopenapi')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RelationId(self):
+	def get_RelationId(self): # Long
 		return self.get_query_params().get('RelationId')
 
-	def set_RelationId(self,RelationId):
-		self.add_query_param('RelationId',RelationId)
\ No newline at end of file
+	def set_RelationId(self, RelationId):  # Long
+		self.add_query_param('RelationId', RelationId)
